@@ -11,6 +11,7 @@ from m3_rest_gar.views import (
     AddrObjViewSet,
     ApartmentsViewSet,
     HousesViewSet,
+    SteadsViewSet,
     RoomsViewSet,
 )
 
@@ -18,6 +19,7 @@ from m3_rest_gar.views import (
 router = routers.DefaultRouter()
 router.register('addrobj', AddrObjViewSet, basename='addrobj')
 router.register('houses', HousesViewSet, basename='houses')
+router.register('steads', SteadsViewSet, basename='steads')
 router.register('apartments', ApartmentsViewSet, basename='apartments')
 router.register('rooms', RoomsViewSet, basename='rooms')
 
